@@ -1,8 +1,8 @@
 #' @title Dot Density layer
 #' @name dotDensityLayer
 #' @description Plot a dot density layer.
-#' @param spdf SpatialPointsDataFrame or SpatialPolygonsDataFrame; if spdf 
-#' is a SpatialPolygonsDataFrame symbols are plotted on centroids.
+#' @param x an sf object, a simple feature collection. If x is used then spdf, df, spdfid and dfid are not. 
+#' @param spdf a SpatialPolygonsDataFrame. 
 #' @param df a data frame that contains the values to plot. If df is missing 
 #' spdf@data is used instead. 
 #' @param spdfid id field in spdf, default to the first column 
@@ -39,19 +39,13 @@
 #' 
 #' 
 #' # Example 2
-#' layoutLayer(title = "Population in Europe, 2008", 
-#'             sources = "Eurostat, 2008", 
-#'             scale = NULL, 
-#'             frame = TRUE,
-#'             col = "black", 
-#'             coltitle = "white",
-#'             bg = "#E6E6E6", 
-#'             extent = nuts0.spdf)
-#' plot(nuts1.spdf, col = "#B8704D50",border = "white", add=TRUE)
-#' dotDensityLayer(spdf = nuts1.spdf, df=nuts1.df,var="pop2008",
-#'                 type = "regular", pch=20, col = "brown",
-#'                 n = 100000)
-dotDensityLayer <- function(spdf, df, spdfid = NULL, dfid = NULL, var,
+#' mtq <- st_read(system.file("shape/martinique.shp", package="cartography"))
+#' plot(st_geometry(mtq), col = "#B8704D50",border = "white")
+#' dotDensityLayer(x = mtq,  var="P13_POP", pch=20, col = "brown", n = 50)
+#' layoutLayer(title = "Population in Martinique, 2013", 
+#'             sources = "INSEE, 2016", scale = NULL, frame = FALSE,
+#'             theme = "brown.pal")
+dotDensityLayer <- function(x, spdf, df, spdfid = NULL, dfid = NULL, var,
                             n = NULL, # Un point vaut nb units
                             iter = 5,
                             pch = 1,
@@ -64,13 +58,19 @@ dotDensityLayer <- function(spdf, df, spdfid = NULL, dfid = NULL, var,
                             legend.col = "black",
                             legend.frame = TRUE,
                             add = TRUE){
-
-  if (missing(df)){df <- spdf@data}
-  if (is.null(spdfid)){spdfid <- names(spdf@data)[1]}
-  if (is.null(dfid)){dfid <- names(df)[1]}
+  if(!missing(x)){
+    spdf <- methods::as(x, 'Spatial')
+    names(spdf@data)[names(spdf@data)==var] <- "var"
+    
+  }else{
+    if (missing(df)){df <- spdf@data}
+    if (is.null(spdfid)){spdfid <- names(spdf@data)[1]}
+    if (is.null(dfid)){dfid <- names(df)[1]}
+    
+    spdf@data <- data.frame(spdf@data, var = df[match(spdf@data[,spdfid], 
+                                                      df[,dfid]),var])
+  }
   
-  spdf@data <- data.frame(spdf@data, var = df[match(spdf@data[,spdfid], 
-                                                    df[,dfid]),var])
   spdf@data[is.na(spdf@data$var),"var"] <- 0
   if (is.null(n)){n <- round(sum(spdf@data$var)/5000,-3)}
   spdf@data$ndots <- as.integer(spdf@data$var/n)
@@ -80,9 +80,7 @@ dotDensityLayer <- function(spdf, df, spdfid = NULL, dfid = NULL, var,
     sp::plot(spdf, col = NA, border = NA)
   }
   
-  
   for (i in 1:nrow(spdf)){
-    #points(spsample(spdf[i,], n = spdf@data[i,"ndots"], type = dots.type), pch = dots.pch, cex= dots.cex)
     plot(spsample(spdf[i,], n = spdf@data[i,"ndots"], type = type, 
                   iter = iter), pch = pch, cex= cex , col=col, 
          add=TRUE)
